CREATE TABLE url (
  rec_id	  int(11) NOT NULL auto_increment,
  status	  smallint(6) DEFAULT '0' NOT NULL,
  docsize	  int(11) DEFAULT '0' NOT NULL,
  next_index_time INT NOT NULL,
  last_mod_time	  INT DEFAULT '0' NOT NULL,
  referrer	  int(11) DEFAULT '0' NOT NULL,
  hops		  smallint(6) DEFAULT '0' NOT NULL,
  crc32		  int(11)	DEFAULT '-1' NOT NULL,
  seed		  smallint(6) DEFAULT '0' NOT NULL,
  bad_since_time  INT NOT NULL,
  server_id	  int(11),
  shows           int(11) DEFAULT '0' NOT NULL,
  url		  TEXT BINARY NOT NULL,
  PRIMARY KEY (rec_id),
  UNIQUE url (url(255)),
  KEY key_crc (crc32),
  KEY key_seed (seed),
  KEY key_referrer (referrer),
  KEY key_bad_since_time (bad_since_time),
  KEY key_next_index_time (next_index_time, seed, rec_id),
  KEY key_server_id (server_id),
  KEY key_status (status),
  KEY key_hops (hops)
) MAX_ROWS=300000000 AVG_ROW_LENGTH=512;


CREATE TABLE urlinfo (
  url_id INT NOT NULL,
  sname  VARCHAR(32)  NOT NULL,
  sval   MEDIUMTEXT         NOT NULL,
  KEY    urlinfo_id  (url_id)
) MAX_ROWS=300000000 AVG_ROW_LENGTH=512;


CREATE TABLE cachedcopy (
  url_id INT NOT NULL,
  ts INT NOT NULL,
  content MEDIUMBLOB   NOT NULL,
  KEY (url_id),
  KEY (ts)
) MAX_ROWS=300000000 AVG_ROW_LENGTH=32000
/*!50100 PARTITION BY HASH (url_id div 65536) PARTITIONS 32 */;


CREATE TABLE dict (
  url_id int(11) DEFAULT '0' NOT NULL,
  word varchar(32) DEFAULT '' NOT NULL,
  coord int(11) DEFAULT '0' NOT NULL,
  KEY url_id (url_id),
  KEY word_url (word)
);

CREATE TABLE bdict (
  word VARCHAR(255) NOT NULL,
  secno TINYINT UNSIGNED NOT NULL,
  coords LONGBLOB NOT NULL,
  KEY(word)
) MAX_ROWS=300000000 AVG_ROW_LENGTH=512;


CREATE TABLE qtrack (
  rec_id  int(11) NOT NULL auto_increment,
  ip      varchar(16) NOT NULL,
  qwords  TEXT NOT NULL,
  qtime   int(11) DEFAULT '0' NOT NULL,
  wtime   int(11) DEFAULT '0' NOT NULL,
  nfound  int(11) DEFAULT '0' NOT NULL,
  PRIMARY KEY (rec_id),
  KEY qtrack_ipt (ip, qtime)
);

#
# keep "qinfo_nv" index name less than 1000 bytes,
# i.e. less than 333 characters, for 4.1+ with UTF-8.
#
CREATE TABLE qinfo (
       q_id  int(11),
       sname varchar(128),
       sval  varchar(255),
       KEY qinfo_id (q_id),
       KEY qinfo_nv (sname, sval(128))
);


create table server (
	rec_id		int null primary key,
	enabled		int		not null	default 0,
	url		BLOB		not null,
	tag		TEXT		not null,
	command		char(1)		not null	default 'S',
	ordre		int		not null	default 0,
	parent		int		not null	default 0,
	weight		float		not null	default 1,
	pop_weight	float		not null	default 0,
	KEY srv_ordre (ordre),
	KEY srv_parent (parent),
	KEY srv_command (command),
	KEY srv_tag(tag(16)),
	UNIQUE srv_url(url(255))
);

CREATE TABLE srvinfo (
       srv_id int  NOT NULL,
       sname  text NOT NULL,
       sval   text NOT NULL,
       KEY srvinfo_id (srv_id)
);


CREATE TABLE `links` (
  `url_id` INT NOT NULL,
  `seed`   SMALLINT NOT NULL,
  `url`    TEXT BINARY NOT NULL,
  `src`    VARCHAR(10) NOT NULL,
  `rel`    VARCHAR(32) NOT NULL,
  `linktext` TEXT NOT NULL,
  KEY `url_id` (`url_id`),
  KEY `seed` (`seed`)
) MAX_ROWS=300000000 AVG_ROW_LENGTH=512
/*!50100 PARTITION BY RANGE (seed)
(PARTITION p00 VALUES LESS THAN (16),
 PARTITION p10 VALUES LESS THAN (32),
 PARTITION p20 VALUES LESS THAN (48),
 PARTITION p30 VALUES LESS THAN (64),
 PARTITION p40 VALUES LESS THAN (80),
 PARTITION p50 VALUES LESS THAN (96),
 PARTITION p60 VALUES LESS THAN (112),
 PARTITION p70 VALUES LESS THAN (128),
 PARTITION p80 VALUES LESS THAN (144),
 PARTITION p90 VALUES LESS THAN (160),
 PARTITION pA0 VALUES LESS THAN (176),
 PARTITION pB0 VALUES LESS THAN (192),
 PARTITION pC0 VALUES LESS THAN (208),
 PARTITION pD0 VALUES LESS THAN (224),
 PARTITION pE0 VALUES LESS THAN (240),
 PARTITION pF0 VALUES LESS THAN (256)) */
;


CREATE TABLE redirect (
  url_id INT NOT NULL,
  seed SMALLINT NOT NULL,
  url  TEXT BINARY NOT NULL,
  KEY(url_id),
  KEY(seed)
);


CREATE TABLE wrdstat (
  word varchar(64) NOT NULL,
  snd varchar(64) NOT NULL,
  cnt int(11) NOT NULL,
  KEY word (word),
  KEY snd (snd)
);

CREATE TABLE qcache (
  id      int not null,
  tm      int not null,
  doclist longblob not null,
  wordinfo text not null,
  primary key qcache_id (id,tm),
  key qcache_tmstamp (tm)
);

-- TODO for qcache
-- id      - CRC sum of qstring variables
-- tmstamp - query date
-- qstring - values affecting query results
-- qextprm - values not affecting query results, like ps and np
-- doclist - result: a list off (url_id, coord) pairs, if
--             actual search was done. NULL if query was taken
--	     from cache.
-- qcache=yes,full,short,no
